==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/HostPathVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling. */
final case class HostPathVolumeSource(
  path : String,
  `type` : Option[String] = None
) {

  /** Returns a new data with path set to new value */
  def withPath(value: String) : HostPathVolumeSource = copy(path = value)
  /** transforms path to result of function */
  def mapPath(f: String => String) : HostPathVolumeSource = copy(path = f(path))

  /** Returns a new data with `type` set to new value */
  def withType(value: String) : HostPathVolumeSource = copy(`type` = Some(value))
  /** if `type` has a value, transforms to the result of function*/
  def mapType(f: String => String) : HostPathVolumeSource = copy(`type` = `type`.map(f))
}

object HostPathVolumeSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.HostPathVolumeSource, T] = new Encoder[io.k8s.api.core.v1.HostPathVolumeSource, T] {
        def apply(o: io.k8s.api.core.v1.HostPathVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("path", o.path)
            .write("type", o.`type`)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, HostPathVolumeSource] = new Decoder[T, HostPathVolumeSource] {
      def apply(t: T): Either[String, HostPathVolumeSource] = for {
          obj <- ObjectReader(t)
          path <- obj.read[String]("path")
          `type` <- obj.readOpt[String]("type")
      } yield HostPathVolumeSource (
          path = path,
          `type` = `type`
        )
    }
}

==> scala-k8s-objects_3-0.8.1-sources.jar: io/k8s/api/core/v1/HostPathVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling. */
final case class HostPathVolumeSource(
  path : String,
  `type` : Option[String] = None
) {

  /** Returns a new data with path set to new value */
  def withPath(value: String) : HostPathVolumeSource = copy(path = value)
  /** transforms path to result of function */
  def mapPath(f: String => String) : HostPathVolumeSource = copy(path = f(path))

  /** Returns a new data with `type` set to new value */
  def withType(value: String) : HostPathVolumeSource = copy(`type` = Some(value))
  /** if `type` has a value, transforms to the result of function*/
  def mapType(f: String => String) : HostPathVolumeSource = copy(`type` = `type`.map(f))
}

object HostPathVolumeSource {

    implicit val encoder : Encoder[io.k8s.api.core.v1.HostPathVolumeSource] = new Encoder[io.k8s.api.core.v1.HostPathVolumeSource] {
        def apply[T : Builder](o: io.k8s.api.core.v1.HostPathVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("path", o.path)
            .write("type", o.`type`)
            .build
        }
    }

    implicit val decoder: Decoder[HostPathVolumeSource] = new Decoder[HostPathVolumeSource] {
      def apply[T : Reader](t: T): Either[String, HostPathVolumeSource] = for {
          obj <- ObjectReader(t)
          path <- obj.read[String]("path")
          `type` <- obj.readOpt[String]("type")
      } yield HostPathVolumeSource (
          path = path,
          `type` = `type`
        )
    }
}
